@@ -1,5 +1,5 @@
 /*
- *    Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+ *    Copyright (C) 1998,1999,2000,2001 Nikos Mavroyanopoulos
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 /* Some functions that didn't fit elsewhere */
 
-/* $Id: extra.c,v 1.10 2001/09/09 09:54:30 nmav Exp $ */
+/* $Id: extra.c,v 1.11 2001/09/15 09:41:37 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -31,13 +31,24 @@
 #include <errors.h>
 #ifndef NO_GETPASS
 # include <getpass.h>
+#else
+# define _mcrypt_getpass getpass
 #endif
 #include <keys.h>
 #include <bits.h>
 #include "mcrypt_int.h"
 
 static char rcsid[] =
-    "$Id: extra.c,v 1.10 2001/09/09 09:54:30 nmav Exp $";
+    "$Id: extra.c,v 1.11 2001/09/15 09:41:37 nmav Exp $";
+
+#ifndef NO_GETPASS
+	#define FREE_STR(x) \
+		_secure_mcrypt_free(x, strlen(x))
+#else
+	#define FREE_STR(x) \
+		Bzero(x, strlen(x))
+#endif
+
 
 extern int double_check;
 extern char *outfile;
@@ -54,41 +65,42 @@ char *my_getpass(char *prt)
 	char *btmp;
 	char string_tmp[200];
 
-	atmp = getpass(prt);
-
+	if (ztmp==NULL) return NULL;
+	
+	atmp = _mcrypt_getpass(prt);
+	if (atmp==NULL) {
+		_secure_mcrypt_free(ztmp, MAX_KEY_LEN);
+		return NULL;
+	}
+	
 	Bzero(string_tmp, sizeof(string_tmp));
 	Bzero(ztmp, MAX_KEY_LEN);
 	strlcpy(ztmp, atmp, MAX_KEY_LEN);
 
-#ifndef NO_GETPASS
-	_secure_mcrypt_free(atmp, strlen(atmp));
-#else
-	Bzero(atmp, strlen(atmp));
-#endif
+	FREE_STR(atmp);
 
 	strcpy(string_tmp, _("Re-"));
 	strcat(string_tmp, prt);
 
-	btmp = getpass(string_tmp);
+	btmp = _mcrypt_getpass(string_tmp);
+	if (btmp==NULL) {
+		_secure_mcrypt_free(ztmp, MAX_KEY_LEN);
+		return NULL;
+	}
 
 	if (strcmp(ztmp, btmp) != 0) {
 		fprintf(stderr,
 			_
 			("Keywords do not match or they are too long.\n"));
-#ifndef NO_GETPASS
-		_secure_mcrypt_free(btmp, MAX_KEY_LEN);
-#else
-		Bzero(btmp, strlen(btmp));
-#endif
+
+		FREE_STR( btmp);
+		
 		_secure_mcrypt_free(ztmp, MAX_KEY_LEN);
 		return NULL;
 	}
-#ifndef NO_GETPASS
-	_secure_mcrypt_free(btmp, MAX_KEY_LEN);
-#else
-	Bzero(btmp, strlen(btmp));
-#endif
-
+	
+	FREE_STR( btmp);
+	
 	return ztmp;
 }
 
@@ -112,7 +124,7 @@ char *get_password(int numofchar, int mode, unsigned int *len, void *salt)
 
 	} else {
 		if (double_check == FALSE) {
-			tmp = getpass(msg);
+			tmp = _mcrypt_getpass(msg);
 		} else {
 			tmp = my_getpass(msg);
 		}
@@ -364,7 +376,7 @@ int write_file_head(FILE * filedes, char *algorithm, char *mode,
 	} else
 		return 1;
 		
-	if (fwrite(tmp, 1, strlen(tmp), filedes) != strlen(buf)) {
+	if (fwrite(tmp, 1, strlen(tmp), filedes) != strlen(tmp)) {
 		return 1;
 	}
 	if (fwrite(&null, 1, 1, filedes)!=1) return 1;
