@@ -361,7 +361,7 @@ num = 0; \
 if(!OK) \
 { \
 num = 0;                                                            \
-target = malloc((gaa_last_non_option - gaa_index) * sizeof(type));  \
+target = _mcrypt_malloc((gaa_last_non_option - gaa_index) * sizeof(type));  \
 for(; gaa_index < gaa_last_non_option; gaa_index++)                 \
 {                                                                   \
     if(gaa_arg_used[gaa_index] == 0)                                \
@@ -378,7 +378,7 @@ if(num == 0)                                                        \
 if(!OK) \
 { \
 num = 0;                                                            \
-target = malloc((gaa_last_non_option - gaa_index) * sizeof(type));  \
+target = _mcrypt_malloc((gaa_last_non_option - gaa_index) * sizeof(type));  \
 for(; gaa_index < gaa_last_non_option; gaa_index++)                 \
 {                                                                   \
     if(gaa_arg_used[gaa_index] == 0)                                \
@@ -950,7 +950,7 @@ int gaa(int argc, char **argv, gaainfo *gaaval)
     GAAargv = argv;
     GAAargc = argc;
 
-    opt_list = (char*) malloc(GAA_NB_OPTION + 1);
+    opt_list = (char*) _mcrypt_malloc(GAA_NB_OPTION + 1);
     for(i = 0; i < GAA_NB_OPTION + 1; i++)
         opt_list[i] = 0;
     /* initialization */
@@ -970,7 +970,7 @@ int gaa(int argc, char **argv, gaainfo *gaaval)
     }
     inited = 1;
 #line 438 "gaa.skel"
-    gaa_arg_used = malloc(argc * sizeof(char));
+    gaa_arg_used = _mcrypt_malloc(argc * sizeof(char));
     for(i = 1; i < argc; i++)
         gaa_arg_used[i] = 0;
     for(i = 1; i < argc; i++)
@@ -1066,8 +1066,8 @@ if(gaa_processing_file == 0)
             return 0;
         }
     }
-    free(gaa_arg_used);
-    free(opt_list);
+    _mcrypt_free(gaa_arg_used);
+    _mcrypt_free(opt_list);
     return -1;
 }
 
@@ -1109,7 +1109,7 @@ int gaa_internal_get_next_str(FILE *file, gaa_str_node *tmp_str, int argc)
         if(fscanf(file,"%c", &a) != 1) a = ' ';
     }
     
-    tmp_str->str = malloc((len + 1) * sizeof(char));
+    tmp_str->str = _mcrypt_malloc((len + 1) * sizeof(char));
     if(newline == 1)
     {
         tmp_str->str[0] = '-';
@@ -1161,7 +1161,7 @@ int gaa_file(char *name, gaainfo *gaaval)
     do
     {
         argc++;
-        *tmp_str = malloc(sizeof(gaa_str_node));
+        *tmp_str = _mcrypt_malloc(sizeof(gaa_str_node));
         (*tmp_str)->str = NULL;
         (*tmp_str)->next = NULL;
 
@@ -1173,7 +1173,7 @@ int gaa_file(char *name, gaainfo *gaaval)
     if(rval == 1)
         return 0;
     
-    argv = malloc((1 + argc) * sizeof(char*));
+    argv = _mcrypt_malloc((1 + argc) * sizeof(char*));
     tmp_str2 = first_str;
     argv[0] = "cfg";
     for(i = 1; i < argc; i++)
