@@ -43,7 +43,7 @@
 
 #include <conio.h>
 
-char* getpass(char* msg) {
+char* _mcrypt_getpass(char* msg) {
 static char pass[512];
 _cputs(msg);
 _cgets(pass);
@@ -91,6 +91,8 @@ char *
 	char *cp, *ap, c;
 	int i;
 
+	if (input==NULL) return NULL;
+	
 	/* putc(' ', stderr); */
 	fflush(stderr);
 
@@ -152,6 +154,8 @@ char *
 	char* input=_secure_mcrypt_malloc(MAXLEN + 1);
 	char *cp;
 
+	if (input==NULL) return NULL;
+	
 	fflush(stderr);
 	if (fgets(input, MAXLEN+1, fp) == input) {
 		if ((cp = strchr(input, '\n')))
@@ -168,7 +172,7 @@ char *
 }
 
 char *
- getpass(const char *prompt)
+ _mcrypt_getpass(const char *prompt)
 {
 	static char nostring[1] = "";
 	static char *return_value;
